@@ -78,6 +78,9 @@ GType arv_chunk_parser_status_get_type	(void) G_GNUC_CONST;
 
 /* Enumerations from "arvgvstream.h" */
 
+#define ARV_TYPE_GV_STREAM_OPTION	(arv_gv_stream_option_get_type())
+GType arv_gv_stream_option_get_type	(void) G_GNUC_CONST;
+
 #define ARV_TYPE_GV_STREAM_SOCKET_BUFFER	(arv_gv_stream_socket_buffer_get_type())
 GType arv_gv_stream_socket_buffer_get_type	(void) G_GNUC_CONST;
 
